<?php

namespace Drupal\media_jove;

use Drupal\Core\Url;

/**
 * Class JoveUrlResolver.
 *
 * @package Drupal\media_jove
 */
class JoveUrlResolver implements JoveUrlResolverInterface {

  /**
   * Base URL for JoVE embedded videos.
   *
   * @var string
   */
  protected $baseUrl = 'https://www.jove.com/embed/player';

  /**
   * {@inheritdoc}
   */
  public function getVideoIdFromEmbedCode($embedCode) {
    // A special case when user can enter the video ID.
    if ((int) $embedCode != 0 && ((int) $embedCode) == $embedCode) {
      return (int) $embedCode;
    }

    // Possible values of embed URLs.
    // https://www.jove.com/video/59216/cortisol-measurement-in-koala-phascolarctos-cinereus-fur
    // https://www.jove.com/science-education/5201/an-introduction-to-neurophysiology
    // https://www.jove.com/embed/directions/59216
    // https://www.jove.com/embed/player?id=50306&t=1&a=1&i=1&chap=1&s=1
    $patterns = array(
      '@jove\.com/v/([0-9]+)@i',
      '@jove\.com/v/([0-9]+)/([^"#\&\? ]+)@i',
      '@jove\.com/video/([0-9]+)@i',
      '@jove\.com/video/([0-9]+)/([^"#\&\? ]+)@i',
      '@jove\.com/science-education/([0-9]+)/([^"#\&\? ]+)@i',
      '@jove\.com/embed/directions/([0-9]+)@i',
      '@jove\.com/embed/player[#\?].*?id=([0-9]+)@i',
    );

    foreach ($patterns as $pattern) {
      preg_match_all($pattern, $embedCode, $matches);
      if (isset($matches[1][0])) {
        return (int) $matches[1][0];
      }
    }

    // If we couldn't parse embed code then flow is broken.
    throw new \InvalidArgumentException('Invalid JoVE url or embed code.');
  }

  /**
   * {@inheritdoc}
   */
  public function getEmbedUrl($id) {
    return Url::fromUri($this->baseUrl, ['query' => ['id' => $id]]);
  }

}
